@@ -66,7 +66,7 @@ class HttpClient(object):
         return self.auth
 
     def _do_request(self, http_method, rest_command,
-                    parameters=None, file=None, data=None,
+                    parameters=None, file=None, data=None, json=None,
                     headers=None, retries=0):
         """Perform a HTTP request.
 
@@ -101,6 +101,7 @@ class HttpClient(object):
                                                      cmd_url,
                                                      params=parameters,
                                                      data=data,
+                                                     json=json,
                                                      timeout=utils.TIMEOUT,
                                                      verify=False,
                                                      headers=headers,
@@ -171,9 +172,11 @@ class HttpClient(object):
         return self._do_request('GET', rest_command, parameters,
                                 headers=headers)
 
-    def _post(self, rest_command, file=None, parameters=None, headers=None, data=None):
+    def _post(self, rest_command, file=None, parameters=None, headers=None,
+              data=None, json=None):
         return self._do_request('POST', rest_command, parameters=parameters,
-                                file=file, data=data)
+                                file=file, data=data, json=json,
+                                headers=headers)
 
 
 class AccessInfoMixin(object):
