@@ -12,6 +12,7 @@ from python_kemptech_api.exceptions import (
     RealServerMissingVirtualServiceInfo,
     RealServerMissingLoadmasterInfo,
     VirtualServiceACLMissingVirtualServiceInfo,
+    LDAPMissingLoadMasterInfo,
     ValidationError,
     RuleMissingLoadmasterInfo,
     RangeMissingLoadmasterInfo,
@@ -142,6 +143,42 @@ class VirtualService(BaseKempObject):
 
         # ESP
         "espenabled": "EspEnabled",
+        "allowedhosts": "AllowedHosts",
+        "alloweddirectories": "AllowedDirectories",
+        "domain": "Domain",
+        "logoff": "Logoff",
+        "addauthheader": "AddAuthHeader",
+        "displaypubpriv": "DisplayPubPriv",
+        "disablepasswordform": "DisablePasswordForm",
+        "captcha": "Captcha",
+        "captchapublickey": "CaptchaPublicKey",
+        "captchaprivatekey": "CaptchaPublicKey",
+        "captchaaccessurl": "CaptchaAccessUrl",
+        "captchaverifyurl": "CaptchaVerifyUrl",
+        "esplogs": "ESPLogs",
+        "smtpalloweddomains": "SMTPAllowedDomains",
+        "excludedirectories": "ExcludeDirectories",
+        "inputauthmode": "InputAuthMode",
+        "outputauthmode": "OutputAuthMode",
+        "serverfbapath": "ServerFbaPath",
+        "serverfbapost": "ServerFBAPost",
+        "serverfbausernameonly": "ServerFbaUsernameOnly",
+        "outconf": "OutConf",
+        "singlesignondir": "SingleSignOnDir",
+        "singlesignonmessage": "SingleSignOnMessage",
+        "allowedgroups": "AllowedGroups",
+        "groupsids": "GroupSIDs",
+        "includenestedgroups": "IncludeNestedGroups",
+        "steeringgroups": "SteeringGroups",
+        "verifybearer": "VerifyBearer",
+        "bearercertificatename": "BearerCertificateName",
+        "bearertext": "BearerText",
+        "excludeddomains": "BearerText",
+        "altdomains": "AltDomains",
+        "userpwdchangeurl": "UserPwdChangeURL",
+        "userpwdchangemsg": "UserPwdChangeMsg",
+        "userpwdexpirywarn": "UserPwdExpiryWarn",
+        "userpwdexpirywarndays": "UserPwdExpiryWarnDays",
     }
     _ESP_PARAMS = [
         "espenabled"
@@ -489,7 +526,43 @@ class VirtualService(BaseKempObject):
         self.intercept = params.get('Intercept', None)
         # ESP
         self.espenabled = params.get('EspEnabled', None)
-
+        self.espenabled = params.get("EspEnabled", None)
+        self.allowedhosts = params.get("AllowedHosts", None)
+        self.alloweddirectories = params.get("AllowedDirectories", None)
+        self.domain = params.get("Domain", None)
+        self.logoff = params.get("Logoff", None)
+        self.addauthheader = params.get("AddAuthHeader", None)
+        self.displaypubpriv = params.get("DisplayPubPriv", None)
+        self.disablepasswordform = params.get("DisablePasswordForm", None)
+        self.captcha = params.get("Captcha", None)
+        self.captchapublickey = params.get("CaptchaPublicKey", None)
+        self.captchaprivatekey = params.get("CaptchaPublicKey", None)
+        self.captchaaccessurl = params.get("CaptchaAccessUrl", None)
+        self.captchaverifyurl = params.get("CaptchaVerifyUrl", None)
+        self.esplogs = params.get("ESPLogs", None)
+        self.smtpalloweddomains = params.get("SMTPAllowedDomains", None)
+        self.excludedirectories = params.get("ExcludeDirectories", None)
+        self.inputauthmode = params.get("InputAuthMode", None)
+        self.outputauthmode = params.get("OutputAuthMode", None)
+        self.serverfbapath = params.get("ServerFbaPath", None)
+        self.serverfbapost = params.get("ServerFBAPost", None)
+        self.serverfbausernameonly = params.get("ServerFbaUsernameOnly", None)
+        self.outconf = params.get("OutConf", None)
+        self.singlesignondir = params.get("SingleSignOnDir", None)
+        self.singlesignonmessage = params.get("SingleSignOnMessage", None)
+        self.allowedgroups = params.get("AllowedGroups", None)
+        self.groupsids = params.get("GroupSIDs", None)
+        self.includenestedgroups = params.get("IncludeNestedGroups", None)
+        self.steeringgroups = params.get("SteeringGroups", None)
+        self.verifybearer = params.get("VerifyBearer", None)
+        self.bearercertificatename = params.get("BearerCertificateName", None)
+        self.bearertext = params.get("BearerText", None)
+        self.excludeddomains = params.get("BearerText", None)
+        self.altdomains = params.get("AltDomains", None)
+        self.userpwdchangeurl = params.get("UserPwdChangeURL", None)
+        self.userpwdchangemsg = params.get("UserPwdChangeMsg", None)
+        self.userpwdexpirywarn = params.get("UserPwdExpiryWarn", None)
+        self.userpwdexpirywarndays = params.get("UserPwdExpiryWarnDays", None)
         # Set meta values for whether WAF and ESP are enabled
         if self.alertthreshold is None or int(self.alertthreshold) == 0:
             self._waf = False
@@ -705,6 +778,82 @@ class RealServer(BaseKempObject):
         self.refresh()
 
 
+class LDAP(BaseKempObject):
+    _API_ADD = "/addldapendpoint"
+    _API_MOD = "/modifyldapendpoint"
+    _API_DELETE = "/deleteldapendpoint"
+    _API_GET = "/showldapendpoint"
+    _API_LIST = "/showldaplist"
+    API_TAG = "LDAP"
+    API_INIT_PARAMS = {
+        "ip": "Addr",
+        "port": "Port"
+    }
+    _API_BASE_PARAMS = [
+        "name"
+    ]
+    _API_DEFAULT_ATTRIBUTES = {
+        "name": "name",
+        "ldaptype": "ldaptype",
+        "server": "server",
+        "vinterval": "vinterval",
+        "referralcount": "referralcount",
+        "timeout": "timeout",
+        "adminuser": "adminuser",
+        "adminpass": "adminpass"
+    }
+
+    @property
+    def ldap(self):
+        return self.server
+
+    def to_api_dict(self):
+        # Populate RS field into dictionary manually
+        as_dict = super(LDAP, self).to_api_dict()
+        as_dict['LDAP'] = self.ldap
+        return as_dict
+
+    def __init__(self, loadmaster_info,  LDAP_obj):
+        self.ldaptype = LDAP_obj.get('ldaptype', 0)
+        self.server = LDAP_obj.get('server', None)
+        self.vinterval = LDAP_obj.get('vinterval',60)
+        self.referralcount = LDAP_obj.get('referralcount', None)
+        self.timeout = LDAP_obj.get('timeout', 5)
+        self.adminuser = LDAP_obj.get('adminuser', None)
+        self.adminpass = LDAP_obj.get('adminpass', None)
+        try:
+            self.name = LDAP_obj['name']
+        except KeyError:
+            raise LDAPMissingLoadMasterInfo("name")
+        try:
+            self.endpoint = loadmaster_info["endpoint"]
+        except KeyError:
+            raise LDAPMissingLoadMasterInfo("endpoint")
+
+        try:
+            self.ip_address = loadmaster_info["ip_address"]
+        except KeyError:
+            raise LDAPMissingLoadMasterInfo("ip_address")
+
+        super(LDAP, self).__init__(loadmaster_info)
+        self.cert = loadmaster_info.get("cert")
+
+    def __str__(self):
+        return 'LDAP {}'.format(self.server)
+
+    def save(self, update=False):
+        super(LDAP, self).save(update)
+
+    def get_ldap_endpoint(self, name=None):
+        if name:
+            response = self._get(self._API_GET, {'name': name})
+        else:
+            response = self._get(self._API_LIST)
+        if is_successful(response):
+            ldap_data = get_data(response)
+            self.populate_default_attributes(ldap_data)
+
+
 class BaseACLObject(BaseKempObject):
     _API = "/aclcontrol"
     _API_ADD = ""
@@ -1082,26 +1231,45 @@ class Sso(BaseKempObject):
         """Populate SSO instance with standard defaults"""
         self.id = params.get('Id', None)
         self.name = params.get('Name', None)
-        self.testuser = params.get('testuser', None)
-        self.ldap_version = params.get('ldap_version', None)
-        self.server_side = params.get('server_side', None)
         self.auth_type = params.get('auth_type', None)
+        self.ldap_endpoint = params.get('ldap_endpoint', None)
+        self.radius_shared_secrret = params.get('radius_shared_secrret', None)
+        self.radius_send_nas_id = params.get('radius_send_nas_id', None)
         self.logon_fmt = params.get('logon_fmt', None)
         self.logon_fmt2 = params.get('logon_fmt2', None)
-        self.logon_transcode = params.get('logon_transcode', None)
         self.logon_domain = params.get('logon_domain', None)
-        self.kerberos_domain = params.get('kerberos_domain', None)
-        self.kerberos_kdc = params.get('kerberos_kdc', None)
-        self.kcd_username = params.get('kcd_username', None)
+        self.logon_transcode = params.get('logon_transcode', None)
         self.max_failed_auths = params.get('max_failed_auths', None)
-        self.reset_fail_tout = params.get('reset_fail_tout', None)
-        self.unblock_tout = params.get('unblock_tout', None)
-        self.sess_tout_type = params.get('sess_tout_type', None)
         self.sess_tout_idle_pub = params.get('sess_tout_idle_pub', None)
         self.sess_tout_duration_pub = params.get('sess_tout_duration_pub', None)
         self.sess_tout_idle_priv = params.get('sess_tout_idle_priv', None)
-        self.sess_tout_duration_priv = params.get('sess_tout_duration_priv', None)
+        self.sess_tout_type = params.get('sess_tout_type', None)
+        self.testuser = params.get('testuser', None)
+        self.testpass = params.get('testpass', None)
+        self.reset_fail_tout = params.get('reset_fail_tout', None)
+        self.unblock_tout = params.get('unblock_tout', None)
+        self.server = params.get('server', None)
+        self.server2 = params.get('server2', None)
+        self.kerberos_domain = params.get('kerberos_domain', None)
+        self.kerberos_kdc = params.get('kerberos_kdc', None)
+        self.kcd_username = params.get('kcd_username', None)
+        self.kcd_password = params.get('kcd_password', None)
+        self.ldap_admin = params.get('ldap_admin', None)
+        self.ldap_password = params.get('ldap_password', None)
         self.cert_check_asi = params.get('cert_check_asi', None)
+        self.cert_check_cn = params.get('cert_check_cn', None)
+        self.server_side = params.get('server_side', None)
+        self.idp_entity_id = params.get('idp_entity_id', None)
+        self.idp_sso_url = params.get('idp_sso_url', None)
+        self.idp_logoff_url = params.get('Idp_logoff_url', None)
+        self.idp_cert = params.get('idp_cert', None)
+        self.idp_match_cert = params.get('idp_match_cert', None)
+        self.sp_entity_id = params.get('sp_entity_id', None)
+        self.sp_cert = params.get('sp_cert', None)
+        self.ldapephc = params.get('ldapephc', None)
+        self.ldap_version = params.get('ldap_version', None)
+        self.sess_tout_duration_priv = params.get('sess_tout_duration_priv', None)
+
 
 
 class Fqdn(BaseKempObject):
