@@ -24,4 +24,11 @@ class LxmlCompatLayerTests(TestCase):
                 xml = f.read()
                 xmltodict_res = xmltodict.parse(xml)
                 lxml_to_dict_res = lxml_to_dict.parse(xml)
-                self.assertDictEqual(xmltodict_res, lxml_to_dict_res)
+                assertion_msg = (
+                    'Incompatibility found between '
+                    'xmltodict and lxml_to_dict in {}'
+                    .format(path))
+                self.assertDictEqual(
+                    xmltodict_res,
+                    lxml_to_dict_res,
+                    assertion_msg)
