@@ -16,14 +16,16 @@ class Test_RealServer:
 
     def setup(self):
         lm_info = {
-            "endpoint": "https://bal:2fourall@1.1.1.1:443/access",
+            "endpoint": "https://1.1.1.1:443/access",
             "ip_address": "1.1.1.1",
+            "auth": ("bal", "2fourall"),
             }
         self.vs = VirtualService(lm_info, "1.1.1.2")
         self.vs_info = {
             'vs': self.vs,
-            "endpoint": "https://bal:2fourall@1.1.1.1:443/access",
+            "endpoint": "https://1.1.1.1:443/access",
             "ip_address": "1.1.1.1",
+            "auth": ("bal", "2fourall"),
             }
         self.rs = RealServer(self.vs_info, "1.1.1.2")
 
@@ -35,7 +37,7 @@ class Test_RealServer:
     def test_init_with_no_ipaddress(self):
         vs_info_with_no_ip_address = {
             'vs': self.vs,
-            "endpoint": "https://bal:2fourall@1.1.1.1:443/access"
+            "endpoint": "https://1.1.1.1:443/access"
             }
         with assert_raises(exceptions.RealServerMissingLoadmasterInfo):
             RealServer(vs_info_with_no_ip_address, "1.1.1.2")
@@ -43,7 +45,7 @@ class Test_RealServer:
     def test_init_with_vs(self):
         vs_info_with_no_vs = {
              "ip_address": "1.1.1.1",
-            "endpoint": "https://bal:2fourall@1.1.1.1:443/access"
+            "endpoint": "https://1.1.1.1:443/access"
             }
         with assert_raises(exceptions.RealServerMissingVirtualServiceInfo):
             RealServer(vs_info_with_no_vs, "1.1.1.2")
